@@ -1037,7 +1037,7 @@ main ( int argc, char **argv)
  next_pass:
   if (configname) {
     configlineno = 0;
-    configfp = fopen (configname, "r");
+    configfp = gnupg_fopen (configname, "r");
     if (!configfp)
       {
         if (default_config)
@@ -1707,7 +1707,7 @@ main ( int argc, char **argv)
 
           filelist[0] = make_filename (gnupg_datadir (),"com-certs.pem", NULL);
           filelist[1] = NULL;
-          if (!access (filelist[0], F_OK))
+          if (!gnupg_access (filelist[0], F_OK))
             {
               log_info (_("importing common certificates '%s'\n"),
                         filelist[0]);
@@ -2213,7 +2213,7 @@ open_read (const char *filename)
   fd = check_special_filename (filename, 0, 0);
   if (fd != -1)
     return fd;
-  fd = open (filename, O_RDONLY | O_BINARY);
+  fd = gnupg_open (filename, O_RDONLY | O_BINARY, 0);
   if (fd == -1)
     {
       log_error (_("can't open '%s': %s\n"), filename, strerror (errno));
