@@ -15,11 +15,9 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, see <https://www.gnu.org/licenses/>.
- * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 #include <config.h>
-
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -34,6 +32,9 @@
 #ifdef HAVE_ZIP
 # include <zlib.h>
 #endif
+#if defined(__riscos__) && defined(USE_ZLIBRISCOS)
+# include "zlib-riscos.h"
+#endif
 
 #define INCLUDED_BY_MAIN_MODULE 1
 #include "../common/util.h"
@@ -65,7 +66,7 @@ enum cmd_and_opt_values {
 };
 
 
-static gpgrt_opt_t opts[] = {
+static ARGPARSE_OPTS opts[] = {
 
     { 301, NULL, 0, "@Options:\n " },
 
@@ -85,11 +86,9 @@ my_strusage (int level)
   const char *p;
   switch (level)
     {
-    case  9: p = "GPL-3.0-or-later"; break;
     case 11: p = "gpgsplit (@GNUPG@)";
       break;
     case 13: p = VERSION; break;
-    case 14: p = GNUPG_DEF_COPYRIGHT_LINE; break;
     case 17: p = PRINTABLE_OS_NAME; break;
     case 19: p = "Please report bugs to <@EMAIL@>.\n"; break;
 
@@ -112,22 +111,19 @@ my_strusage (int level)
 int
 main (int argc, char **argv)
 {
-  gpgrt_argparse_t pargs;
+  ARGPARSE_ARGS pargs;
 
 #ifdef HAVE_DOSISH_SYSTEM
   setmode( fileno(stdin), O_BINARY );
   setmode( fileno(stdout), O_BINARY );
 #endif
   log_set_prefix ("gpgsplit", GPGRT_LOG_WITH_PREFIX);
-  gpgrt_set_strusage (my_strusage);
-  /* Register our string mapper with gpgrt.  Usually done in
-   * init_common_subsystems, but we don't need that here.  */
-  gpgrt_set_fixed_string_mapper (map_static_macro_string);
+  set_strusage (my_strusage);
 
   pargs.argc = &argc;
   pargs.argv = &argv;
-  pargs.flags= ARGPARSE_FLAG_KEEP;
-  while (gpgrt_argparse (NULL, &pargs, opts))
+  pargs.flags=  1;  /* do not remove the args */
+  while (optfile_parse( NULL, NULL, NULL, &pargs, opts))
     {
       switch (pargs.r_opt)
         {
@@ -139,7 +135,6 @@ main (int argc, char **argv)
         default : pargs.err = 2; break;
 	}
     }
-  gpgrt_argparse (NULL, &pargs, NULL);  /* Release internal state.  */
 
   if (log_get_errorcount(0))
     g10_exit (2);
@@ -545,13 +540,19 @@ write_part (FILE *fpin, unsigned long pktlen,
   unsigned char *p;
   const char *outname = create_filename (pkttype);
 
+#if defined(__riscos__) && defined(USE_ZLIBRISCOS)
+  static int initialized = 0;
+
+  if (!initialized)
+      initialized = riscos_load_module("ZLib", zlib_path, 1);
+#endif
   if (opt_no_split)
     fpout = stdout;
   else
     {
       if (opt_verbose)
         log_info ("writing '%s'\n", outname);
-      fpout = fopen (outname, "wb");
+      fpout = gnupg_fopen (outname, "wb");
       if (!fpout)
         {
           log_error ("error creating '%s': %s\n", outname, strerror(errno));
@@ -573,10 +574,7 @@ write_part (FILE *fpin, unsigned long pktlen,
         {
           c = getc (fpin);
           if (c == EOF)
-            {
-              xfree (blob);
-              goto read_error;
-            }
+            goto read_error;
           blob[i] = c;
         }
       len = public_key_length (blob, pktlen);
@@ -588,30 +586,20 @@ write_part (FILE *fpin, unsigned long pktlen,
       if ( (hdr[0] & 0x40) )
         {
           if (write_new_header (fpout, pkttype, len))
-            {
-              xfree (blob);
-              goto write_error;
-            }
+            goto write_error;
         }
       else
         {
           if (write_old_header (fpout, pkttype, len))
-            {
-              xfree (blob);
-              goto write_error;
-            }
+            goto write_error;
         }
 
       for (i=0; i < len; i++)
         {
           if ( putc (blob[i], fpout) == EOF )
-            {
-              xfree (blob);
-              goto write_error;
-            }
+            goto write_error;
         }
 
-      xfree (blob);
       goto ready;
     }
 
@@ -885,7 +873,7 @@ split_packets (const char *fname)
       fp = stdin;
       fname = "-";
     }
-  else if ( !(fp = fopen (fname,"rb")) )
+  else if ( !(fp = gnupg_fopen (fname,"rb")) )
     {
       log_error ("can't open '%s': %s\n", fname, strerror (errno));
       return;
